@@ -1,7 +1,5 @@
 #' @importFrom utils globalVariables
-utils::globalVariables(c("dnapath.mart_species", 
-                         "dnapath.mart_obj", 
-                         "entrezgene_id", 
+utils::globalVariables(c("entrezgene_id", 
                          "symbol"))
 
 #' Obtain Reactome pathways
@@ -41,10 +39,16 @@ utils::globalVariables(c("dnapath.mart_species",
 get_reactome_pathways <- function(species, overlap_limit = 0.9, min_size = 10, 
                                   max_size = 50, verbose = TRUE) {
   if(!requireNamespace("reactome.db", quietly = TRUE)) {
-    message("Warning: The `reactome.db` package must be installed to use get_reactome_pathways().",
-            "Returning the p53_pathway list by default.")
+    message("Warning: The `reactome.db` package must be installed to use ",
+            "get_reactome_pathways(). Returning the p53_pathway list by default.\n")
     return(dnapath::p53_pathways)
   }
+  if(!requireNamespace("AnnotationDbi", quietly = TRUE)) {
+    message("Warning: The `AnnotationDbi` package must be installed to use ",
+            "get_reactome_pathways(). Returning the p53_pathway list by default.\n")
+    return(dnapath::p53_pathways)
+  }
+  
   
   # If species is "human" or "mouse", change to appropriate name.
   if(tolower(species) == "human") 
@@ -52,6 +56,7 @@ get_reactome_pathways <- function(species, overlap_limit = 0.9, min_size = 10,
   if(tolower(species) == "mouse" || tolower(species) == "mice") 
     species <- "Mus musculus"
   
+  
   if(verbose)
     cat("Obtaining reactome pathway information for species:", species, "\n")
   # Get list of reactome pathway names
@@ -61,25 +66,28 @@ get_reactome_pathways <- function(species, overlap_limit = 0.9, min_size = 10,
   
   # library(reactome.db)
   # Map reactome NAME to reactome ID. Subset on pathways for this species.
-  reactome_to_id <- as.list(reactome.db::reactomePATHNAME2ID)
+  reactome_to_id <- reactome.db::reactomePATHNAME2ID
   index <- which(tolower(species) == 
-                   tolower(gsub(":.*", "", 
-                                names(as.list(reactome.db::reactomePATHNAME2ID)))))
+                   tolower(gsub(":.*", "", AnnotationDbi::keys(reactome_to_id))))
   if(length(index) == 0) {
     available_species <- unique(
-      gsub("(: .*)", "", names(as.list(reactome.db::reactomePATHNAME2ID))))
+      gsub("(: .*)", "", names(as.list(reactome_to_id))))
     stop(species, " is not an available species. Use one of the following:\n\t", 
          paste(available_species[-length(available_species)], collapse = ",\n\t"), 
          available_species[length(available_species)], ".")
   }
   reactome_to_id <- reactome_to_id[index]
+  reactome_to_id <- as.list(reactome_to_id)
   
   # Map reactome ID to entrez ID.
-  id_to_entrez <- as.list(reactome.db::reactomePATHID2EXTID)
+  id_to_entrez <- reactome.db::reactomePATHID2EXTID
   
   # Subset on reactome IDs obtained in first step.
-  index <- which(names(id_to_entrez) %in% sapply(reactome_to_id, dplyr::first))
+  # id_to_entrez <- id_to_entrez[sapply(reactome_to_id, dplyr::first)]
+  
+  index <- which(AnnotationDbi::keys(id_to_entrez) %in% sapply(reactome_to_id, dplyr::first))
   id_to_entrez <- id_to_entrez[index]
+  id_to_entrez <- as.list(id_to_entrez)
   
   # Remove any pathways containing fewer than min_size genes or more than 
   # max_size genes.
@@ -87,11 +95,12 @@ get_reactome_pathways <- function(species, overlap_limit = 0.9, min_size = 10,
   id_to_entrez <- id_to_entrez[sizes >= min_size & sizes <= max_size]
   
   # Map reactome ID back to reactome NAME.
-  id_to_reactome <- as.list(reactome.db::reactomePATHID2NAME)
+  id_to_reactome <- reactome.db::reactomePATHID2NAME
   
   # Subset on reactome IDs obtained in previous step.
-  index <- which(names(id_to_reactome) %in% names(id_to_entrez))
+  index <- which(AnnotationDbi::keys(id_to_reactome) %in% names(id_to_entrez))
   id_to_reactome <- id_to_reactome[index]
+  id_to_reactome <- as.list(id_to_reactome)
   
   # Finally, map reactome NAME to entrez ID
   pathway_list <- id_to_entrez
@@ -189,11 +198,14 @@ combine_overlapping_pathways <- function(pathway_list, overlap_limit = 0.9) {
 #' "Homo sapiens", "m musculus", "C. elegans", or "S cerevisiae".
 #' "Human" and "mouse" can also be used and will be converted to the 
 #' correct species name.
+#' @param symbol_name The type of gene symbol to use. If NULL, then "hgnc_symbol"
+#' is used for HGNC symbols, unless `species` is "mmusculus", in which case 
 #' @param dir_save The directory to store annotation reference. Future
 #' calls to this function will use the stored annotations. This speeds up the
 #' operation and allows for reproducibility in the event that the `biomaRt`
 #' database is updated. Set to NULL to disable. By default, it uses a
 #' temporary directory to store files during the R session.
+#' "mgi_symbol" is used.
 #' @param verbose Set to FALSE to avoid messages.
 #' @return A data frame with two columns: the first contains the original
 #' entrezgene IDs, and the second contains the corresponding gene symbols.
@@ -217,9 +229,9 @@ combine_overlapping_pathways <- function(pathway_list, overlap_limit = 0.9) {
 #' }
 entrez_to_symbol <- function(x, 
                              species,
+                             symbol_name = NULL,
                              dir_save = tempdir(),
                              verbose = TRUE) {
-  
   if(class(x) %in% c("dnapath", "dnapath_list")) {
     stop("Input should be a vector of entrezgene IDs, not a dnapath object. ",
          'Use rename_genes() with `to = "symbol"`')
@@ -227,42 +239,15 @@ entrez_to_symbol <- function(x,
   
   species <- format_species_name(species)
   
-  attribute <- "hgnc_symbol"
-  if(species == "mmusculus") {
-    attribute <- "mgi_symbol"
-  }
-  
-  load_file <- NULL
-  if(!is.null(dir_save))
-    load_file <- file.path(dir_save, paste0("entrez_to_", species, ".rds"))
-    
-  if(!is.null(dir_save) && file.exists(load_file)) {
-    if(verbose) cat("\t- loading gene info from", load_file, "\n")
-    gene_info <- readRDS(load_file)
-  } else {
-    if(!all(c("dnapath.mart_obj", "dnapath.mart_species") %in% ls()) || 
-       is.null(dnapath.mart_obj) || is.null(dnapath.mart_species) ||
-       (dnapath.mart_species != species)) 
-      init_mart(species)
-    
-    gene_info <- biomaRt::getBM(attributes = c("entrezgene_id", attribute),
-                                mart = dnapath.mart_obj)
-    gene_info %>%
-      dplyr::filter(!is.na(entrezgene_id)) %>%
-      dplyr::group_by(entrezgene_id) %>%
-      dplyr::summarise(across(everything(), dplyr::first)) ->
-      gene_info
-    
-    # Store the annotations for future reference.
-    if(!is.null(dir_save)) {
-      save_file <- load_file
-      if(verbose)
-        cat("\t- saving gene info to", save_file, "\n")
-      if(!dir.exists(dir_save)) dir.create(dir_save, recursive = TRUE)
-      saveRDS(gene_info, save_file)
+  # Different species will have different names for symbol identifier.
+  if(is.null(symbol_name)) {
+    if(species == "mmusculus") {
+      symbol_name <- "mgi_symbol"
+    } else {
+      symbol_name <- "hgnc_symbol"
     }
   }
-
+  
   # If the entrezgene IDs are a factor or character object, coerce into numeric.
   if(!is.numeric(x)) {
     if(is.factor(x)) {
@@ -272,8 +257,19 @@ entrez_to_symbol <- function(x,
     }
   }
   
-  df <- data.frame(entrezgene_id = x, 
-                   stringsAsFactors = FALSE)
+  gene_info <- get_biomart_mapping(species, symbol_name, dir_save, verbose)
+  
+  # get_biomart_mapping() may return NULL if biomaRt is not installed or
+  # if there is no internet access. Return "NA" string for gene symbols.
+  if(is.null(gene_info)) {
+    df <- data.frame(entrezgene_id = x,
+                    symbol = "NA", 
+                    stringsAsFactors = FALSE)
+    colnames(df)[2] <- symbol_name
+    return(df)
+  }
+  
+  df <- data.frame(entrezgene_id = x)
   df <- dplyr::left_join(df, gene_info, by = "entrezgene_id")
   df <- dplyr::distinct(df)
   
@@ -304,6 +300,9 @@ entrez_to_symbol <- function(x,
 #' "Homo sapiens", "m musculus", "C. elegans", or "S cerevisiae".
 #' "Human" and "mouse" can also be used and will be converted to the 
 #' correct species name.
+#' @param symbol_name The type of gene symbol to use. If NULL, then "hgnc_symbol"
+#' is used for HGNC symbols, unless `species` is "mmusculus", in which case 
+#' "mgi_symbol" is used.
 #' @param dir_save The directory to store annotation reference. Future
 #' calls to this function will use the stored annotations. This speeds up the
 #' operation and allows for reproducibility in the event that the `biomaRt`
@@ -333,6 +332,7 @@ entrez_to_symbol <- function(x,
 #' }
 symbol_to_entrez <- function(x, 
                              species,
+                             symbol_name = NULL,
                              dir_save = tempdir(),
                              verbose = TRUE) {
   
@@ -340,13 +340,97 @@ symbol_to_entrez <- function(x,
     stop("Input should be a vector of entrezgene IDs, not a dnapath object.")
   }
   
+  # If the gene symbols are a factor, coerce into character.
+  if(is.factor(x)) {
+    x <- as.character(x)
+  }
+  
   species <- format_species_name(species)
   
-  attribute <- "hgnc_symbol"
-  if(species == "mmusculus") {
-    attribute <- "mgi_symbol"
+  # Different species will have different names for symbol identifier.
+  if(is.null(symbol_name)) {
+    if(species == "mmusculus") {
+      symbol_name <- "mgi_symbol"
+    } else {
+      symbol_name <- "hgnc_symbol"
+    }
   }
   
+  gene_info <- get_biomart_mapping(species, symbol_name, dir_save, verbose)
+  
+  # get_biomart_mapping() may return NULL if biomaRt is not installed or
+  # if there is no internet access. Return -1 for entrezgene IDs.
+  if(is.null(gene_info)) {
+    df <- data.frame(symbol = x,
+                     entrezgene_id = -1, 
+                     stringsAsFactors = FALSE)
+    colnames(df)[1] <- symbol_name
+    return(df)
+  }
+  
+  df <- data.frame(symbol = x, stringsAsFactors = FALSE)
+  colnames(df) <- symbol_name
+  df <- dplyr::left_join(df, gene_info, by = symbol_name)
+  df <- dplyr::distinct(df)
+  
+  # If any entrezgenes were not found, replace NA value(s) with -1
+  index_na <- which(is.na(df[, 2]))
+  if(length(index_na) > 0) {
+    df[index_na, 2] <- -1
+  }
+  
+  return(df)
+}
+
+
+#' Internal function for obtaining biomaRt mapping
+#'
+#' @param species The species to obtain a biomart dataset for. This should be
+#' an output from \code{\link{format_species_name}}.
+#' @param symbol_name The type of gene symbol to use. HGNC symbols are used by 
+#' default, unless `species` is "mmusculus", in which case MGI symbols are used.
+#' @param dir_save The directory to store annotation reference. Future
+#' calls to this function will use the stored annotations. This speeds up the
+#' operation and allows for reproducibility in the event that the `biomaRt`
+#' database is updated. Set to NULL to disable. By default, it uses a
+#' temporary directory to store files during the R session.
+#' @param verbose Set to FALSE to avoid messages.
+#' @return A data frame containing a mapping between entrezgene IDs and gene 
+#' symbols.
+#' @keywords internal
+#' @export
+get_biomart_mapping <- function(species, symbol_name, dir_save, verbose) {
+  # If biomaRt package is not installed, return default mapping.
+  if(!requireNamespace("biomaRt", quietly = TRUE)) {
+    message("Warning: the bioconductor package `biomaRt` is not installed.\n")
+    if(species == "hsapiens") {
+      message("Warning: Using the biomaRt data archived in `dnapath`; this ",
+              "mapping may be outdated.")
+      gene_info <- dnapath::biomart_hsapiens
+    } else {
+      message("Error: No default biomaRt data available for ", species, ". ", 
+              "Please install the `biomaRt` package.\n")
+      gene_info <- NULL
+    }
+    return(gene_info)
+  }
+  
+  # If no internet access, return default mapping.
+  if(!curl::has_internet()) {
+    message("Warning: Internet connection is not available.\n")
+    if(species == "hsapiens") {
+      message("Warning: Using the biomaRt data archived in `dnapath`; this ",
+              "mapping may be outdated.")
+      gene_info <- dnapath::biomart_hsapiens
+    } else {
+      message("Error: No default biomaRt data available for ", species, ". ", 
+              "Please establish internet connection and try again.\n")
+      gene_info <- NULL
+    }
+    return(gene_info)
+  }
+  
+  
   load_file <- NULL
   if(!is.null(dir_save))
     load_file <- file.path(dir_save, paste0("entrez_to_", species, ".rds"))
@@ -355,28 +439,15 @@ symbol_to_entrez <- function(x,
     if(verbose) cat("\t- loading gene info from", load_file, "\n")
     gene_info <- readRDS(load_file)
   } else {
-    if(!all(c("dnapath.mart_obj", "dnapath.mart_species") %in% ls()) || 
-       is.null(dnapath.mart_obj) || is.null(dnapath.mart_species) ||
-       (dnapath.mart_species != species)) 
-      init_mart(species)
-    
-    gene_info <- biomaRt::getBM(attributes = c("entrezgene_id", attribute),
-                                mart = dnapath.mart_obj)
-    
-    # The order of columns is not fixed (sometimes entrezgene IDs are second).
-    # Identify which column contains the symbols.
-    index_symbol_column <- which(colnames(gene_info) == attribute)[1]
-    colnames(gene_info)[index_symbol_column] <- "symbol"
+    mart <- init_mart(species)
+    gene_info <- biomaRt::getBM(attributes = c("entrezgene_id", symbol_name),
+                                mart = mart)
     gene_info %>%
       dplyr::filter(!is.na(entrezgene_id)) %>%
-      dplyr::group_by(symbol) %>%
-      dplyr::summarise(across(everything(), dplyr::first)) %>%
-      dplyr::ungroup() ->
+      dplyr::group_by(entrezgene_id) %>%
+      dplyr::summarise(across(everything(), dplyr::first)) ->
       gene_info
     
-    # The grouping variable (gene symbol) will now be the first column
-    colnames(gene_info)[1] <- attribute
-    
     # Store the annotations for future reference.
     if(!is.null(dir_save)) {
       save_file <- load_file
@@ -387,54 +458,31 @@ symbol_to_entrez <- function(x,
     }
   }
   
-  # If the gene symbols are a factor, coerce into character.
-  if(is.factor(x)) {
-    x <- as.character(x)
-  }
-  
-  df <- data.frame(symbol = x, 
-                   stringsAsFactors = FALSE)
-  colnames(df) <- attribute
-  df <- dplyr::left_join(df, gene_info, by = attribute)
-  df <- dplyr::distinct(df)
-  
-  # If any symbols were not found, replace NA value(s) with the entrezgene ID.
-  index_na <- which(is.na(df[, 2]))
-  if(length(index_na) > 0) {
-    df[index_na, 2] <- df[index_na, 1]
-  }
-  
-  return(df)
+  return(gene_info)
 }
 
-
-
 #' Initialize biomaRt for a given species
 #'
-#' @param species The species to obtain a biomart dataset for. For example:
-#' "Homo sapiens", "m musculus", "C. elegans", or "S cerevisiae".
-#' "Human" and "mouse" can also be used and will be converted to the 
-#' correct species name.
-#' @return None. Creates/updates the global variables "dnapath.mart_obj" and 
-#' "dnapath.mart_species" used by the 
-#' \code{\link{symbol_to_entrez}} and \code{\link{entrez_to_symbol}} methods.
-#' @note Requires internet connection. If unavailable, the default biomart
-#' and default species contained in the package is used. 
+#' @param species The species to obtain a biomart dataset for. This should be
+#' an output from \code{\link{format_species_name}}.
+#' @return A biomaRt object.
+#' @note Requires internet connection. This function is called by 
+#' \code{\link{get_biomart_mapping}}, which checks for internet connection
+#' prior to calling this function.
 #' @keywords internal
 #' @export
 init_mart <- function(species) {
   # listMarts(); listAttributes(mart) # Useful functions to obtain more info.
   # listDatasets(useMart('ensembl'));
   
-  species <- format_species_name(species)
-  
-  # Obtain the biomaRt for this species.
-  mart_temp <- tryCatch(
+  # Attempt to connect to biomaRt database.
+  message("Connecting to biomaRt database...\n")
+  mart <- tryCatch(
     biomaRt::useMart(biomart = "ensembl", 
                      dataset = paste0(species, "_gene_ensembl")),
     error = function(e) {
       if(!curl::has_internet()) {
-        message("Error: Internet connection must be available.\n")
+        message("Error: Internet connection is not available.\n")
       } else if(!grepl("curl", e)) {
         message("Error: ", paste0('"', species, '"'), " is not an available species.\n",
                 "Example species include: `H. sapiens`, `M. Musculus`, `C. elegans`, etc.\n",
@@ -445,21 +493,10 @@ init_mart <- function(species) {
       return(NULL)
     })
   
-  if(is.null(mart_temp)) {
-    message("Warning: Using default species `H. sapiens`.\n")
-    mart_temp <- dnapath::mart
-    assign("dnapath.mart_obj", mart_temp, inherits = TRUE)
-    assign("dnapath.mart_species", "default", inherits = TRUE)
-  } else {
-    # Save the biomaRt in global environment.
-    assign("dnapath.mart_obj", mart_temp, inherits = TRUE)
-    assign("dnapath.mart_species", species, inherits = TRUE)
-  }
-  
-  return(list(mart_obj = mart_temp, 
-              mart_species = species))
+  return(mart)
 }
 
+
 #' Format sepcies name input.
 #' 
 #' Internal function used to format species names to be used with biomart.
